Package {nomads}


Title: Nomadic Pectoral Sandpiper Movement Data
Version: 0.0.1
Description: Provides satellite tracking data from nomadic pectoral sandpipers published in Kempenaers and Valcu (2017) <doi:10.1038/nature20813>. The data can also serve as benchmark data for clustering movement tracks.
License: CC BY 4.0
Encoding: UTF-8
RoxygenNote: 8.0.0
Depends: R (≥ 4.0)
Suggests: data.table
LazyData: true
NeedsCompilation: no
Packaged: 2026-05-27 14:57:35 UTC; mihai
Author: Mihai Valcu ORCID iD [aut, cre], Bart Kempenaers [ctb]
Maintainer: Mihai Valcu <mvalcu@gwdg.de>
Repository: CRAN
Date/Publication: 2026-05-30 09:00:02 UTC

nomads: Nomadic Wader Movement Data

Description

Provides satellite tracking data from nomadic pectoral sandpipers.

Author(s)

Maintainer: Mihai Valcu mvalcu@gwdg.de (ORCID)

Authors:

Other contributors:


Satellite telemetry locations of male pectoral sandpipers

Description

A processed dataset of Argos satellite telemetry locations for male pectoral sandpipers, Calidris melanotos, tracked during the Arctic breeding season.

Usage

pesa

Format

A data.table with 129536 rows and 7 variables. If data.table is installed when the dataset is loaded, pesa is returned as a keyed data.table.

id

Individual male identifier.

time

Timestamp of the Argos location fix, as POSIXct in UTC.

latitude

Latitude in decimal degrees.

longitude

Longitude in decimal degrees.

site_id

Residency site identifier. Non-site id points are NA

locationClass

Argos location class.

Details

Use-sites were identified in the original analysis using density-based spatial clustering (DBSCAN). This dataset provides a useful benchmark because the original DBSCAN parameters, \epsilon and MinPts, were tuned using a subset of males for which the expected classification was known. Additionally all identified use-sites were also checked visually, with a small number of manual corrections applied where needed. See Kempenaers and Valcu (2017) doi:10.1038/nature20813 for details.

Kempenaers, B. and Valcu, M. (2017). Breeding site sampling across the Arctic by individual males of a polygynous shorebird. Nature. doi:10.1038/nature20813

Data and analysis code were made available at doi:10.17605/OSF.IO/VX2MK under an Open Data Commons Open Database License.

References

Kempenaers, B. and Valcu, M. (2017). Breeding site sampling across the Arctic by individual males of a polygynous shorebird. Nature. doi:10.1038/nature20813

Examples

data(pesa)

head(pesa)
dim(pesa)
names(pesa)

# Number of locations per bird
table(pesa$id)

# Time span covered by the dataset
range(pesa$time)